#ifndef _CODEC_H
#define _CODEC_H

//
// LocoTool - A program to edit Locomotion object description .dat files
//
// Copyright (C) 2004 by Josef Drexler
//
// This file is distributed under the term of the GNU General Public Licence
// version 2 or higher.  Please read the file LICENCE for details.
//
//
// codec.h - functions implementing the various chunk compression/decompression
//	     techniques, plus checksumming
//

#include "common.h"

// RLE decode the given data and return a malloc'ed decoded copy
// (we don't need to return the length because that's "obvious" from the
// contents of the data)
int LocoTool_rledecode(uint8_t *data, uint32_t len, uint8_t **outdata, uint32_t *outlen);

// RLE decode then string decompression
int LocoTool_decompress(uint8_t *data, uint32_t len, uint8_t **outdata, uint32_t *outlen);

// descramble using success bit rotates
int LocoTool_descramble(uint8_t *data, uint32_t len);

// RLE encode the given data, and return a malloc'ed encoded copy plus its
// length in the given parameters
int LocoTool_rleencode(uint8_t *data, uint32_t len, uint8_t **rleout, uint32_t *rlelen);

// scramble using success bit rotates
int LocoTool_scramble(uint8_t *data, uint32_t len);

// calculate the checksum of the RLE decoded data
uint32_t LocoTool_checksum(uint8_t *data, uint32_t len);

#endif // ndef _CODEC_H
