#ifndef _COMMON_H
#define _COMMON_H

//
// LocoTool - A program to edit Locomotion object description .dat files
//
// Copyright (C) 2004 by Josef Drexler
//
// This file is distributed under the term of the GNU General Public Licence
// version 2 or higher.  Please read the file LICENCE for details.
//
//
// common.h - common structures and functions
//

#include <stdint.h>
#include <stdlib.h>
#include <setjmp.h>

#ifdef __linux
#	include <errno.h>
#	define __declspec(a)
#	define CONSOLE
#elifndef CONSOLE
#	define __windows
#endif

#include "locodef.h"

// global variable; if set, will use this structure to return
// using a longjmp after an error
extern jmp_buf* err_return;

// output a formatted error message and abort
void LocoTool_die(const char s[], ...);
#define die LocoTool_die

// for memory leak detection
extern uint32_t totalallocated;

void *my_alloc(size_t len, const char *name);
void *my_realloc(void *p, size_t len, size_t oldlen, const char *name);
char *my_strdup(const char *s, const char *name);
void *_my_free(void *p);

// this macro uses the NULL return code of _my_free to prevent multiple
// attempts to free the variable
#define my_free(x) x=_my_free(x)

// get an unsigned and a signed value of the given size from data
uint32_t getuvalue(uint8_t *data, int size);
int32_t getsvalue(uint8_t *data, int size);
int32_t getvalue(uint8_t *data, int size);

// get size of varinf structure
uint32_t structsize(struct s_varinf *vars);

#endif // ndef _COMMON_H
