//
// LocoTool - A program to edit Locomotion object description .dat files
//
// Copyright (C) 2004 by Josef Drexler
//
// This file is distributed under the term of the GNU General Public Licence
// version 2 or higher.  Please read the file LICENCE for details.
//
//
// locotool.c - the main file
//

#include <stdio.h>
#include <string.h>

#include "locotool.h"
#include "common.h"

#ifndef CONSOLE
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

// called by the dll if anything goes wrong
void err_messagebox(char *message)
{
  MessageBox(NULL,message,LocoTool_get_version(),MB_OK);
}
#endif

const char *helpmsg =
	"Usage: locotool [options] <dat-file|xml-file>\n\n"
	"Options:\n"
	"\t-p <num>: choose company colours\n"
	"\t-d: make .dat file for the demo version\n"
	"\t-o <path>: set base name for png files\n"
	"\t-q: fail quietly (no error messages)\n"
	"\t-s: put all sprites in a single PNG file\n"
	"\t-u: output all <unknown> entries, even if they are zero\n"
	"\t-b: omit defined bits that are not set\n"
	;

int main(int argc, char **argv)
{
  int i, consoleopt;
  char *fname = NULL;

#ifdef CONSOLE
  printf("%s\n", LocoTool_get_version());
  
  LocoTool_set_int_option(opt_nounsetbits, 1);
  LocoTool_set_int_option(opt_allinone, 1);
  consoleopt = 0;
#else
  LocoTool_set_err_handler(err_messagebox);
  consoleopt = 1;
#endif

  for (i=1; i<argc; i++)
	if (argv[i][0] == '-') {
		switch (argv[i][1]) {
			case 'p':
				LocoTool_set_int_option(opt_palettetype, atol(argv[++i]));
				break;
			case 'd':
				LocoTool_set_int_option(opt_demofile, 1);
				break;
			case 'o':
				LocoTool_set_str_option(opt_pngbase, argv[++i]);
				break;
			case 'q':
				LocoTool_set_int_option(opt_quiet, 1);
				break;
			case 's':
				LocoTool_set_int_option(opt_allinone, consoleopt);
				break;
			case 'H':
				LocoTool_set_int_option(opt_heapdebug, 1);
				break;
			case 'u':
				LocoTool_set_int_option(opt_allunknown, 1);
				break;
			case 'b':
				LocoTool_set_int_option(opt_nounsetbits, consoleopt);
				break;
			default:
				LocoTool_die("Unknown command line switch '%c'\n\n%s", argv[i][1], helpmsg);
		}
	} else {
		fname = argv[i];
	}

  if (!fname) LocoTool_die("%s\n\n%s", 
#ifdef CONSOLE
	"",
#else
	LocoTool_get_version(),
#endif
	helpmsg);

  if (stricmp(fname+strlen(fname)-4, ".xml") == 0) {
	LocoTool_encode(fname);
  } else {
	LocoTool_decode(fname);
  }

#ifdef CONSOLE
  if (totalallocated) {
	FILE *leak = fopen("locotool.leak", "wt");
	fputs("Command line:", leak);
	for (i=0; i<argc; i++) fprintf(leak, " %s", argv[i]);
	fprintf(leak, "\nMemory leak warning: %d bytes remain allocated\n\n", totalallocated);
	fclose(leak);
  }
#endif

  return 0;
}
